package weaver.interfaces.zkdpoc;

import com.weaver.general.Util;
import weaver.conn.RecordSet;
import weaver.interfaces.schedule.BaseCronJob;
import weaver.interfaces.zkdpoc.po.SalaryPayProcessPo;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author liang.cheng
 * @Date 2024/10/11 5:39 PM
 * @Description: 中科大POC 更新薪资缴款进度
 * @Version 1.0
 */
public class SalaryPayProcessCrob extends BaseCronJob {


    @Override
    public void execute() {

        List<SalaryPayProcessPo> salaryPayProcessList = new ArrayList<>();

        RecordSet rs = new RecordSet();
        //1.获取需要更新的缴纳情况人数
        rs.executeQuery("select ryxm from uf_ryxzjnqk");
        while (rs.next()) {
            salaryPayProcessList.add(SalaryPayProcessPo.builder().personId(Util.getIntValue(rs.getString("ryxm"))).build());
        }

        LocalDate now = LocalDate.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM");
        String localDate = now.format(formatter);

        salaryPayProcessList.forEach(item -> {
            rs.executeQuery("select yd,ydxz from uf_ryxzbzkd where jkqk = 1 and xm = 1 order by yd desc limit 1");

            if (rs.next()){
                String payMonth = Util.null2String(rs.getString("yd"));
                double ydxz = Util.getDoubleValue("ydxz");
                int monthsDiff = calculateMonthDiff(payMonth,localDate);
               if (monthsDiff > 3) {
                    item.setPayProcess(0);
               }else if (monthsDiff >= 0) {
                    item.setPayProcess(1);
               }else {
                    item.setPayProcess(2);
                    double dueMonth = ydxz * monthsDiff;
                    item.setDueMoney(dueMonth);
                    item.setDueStartMonth(payMonth);
                    item.setDueEndMonth(localDate);
               }

               if (monthsDiff >= 0) {
                   rs.executeUpdate("update uf_ryxzjnqk set jkjd = ? where ryxm = ?",item.getPayProcess(),item.getPersonId());
               }else {
                   rs.executeUpdate("update uf_ryxzjnqk set jkjd = ?,qfsdq = ?,qfsdz = ?,qfje = ? where ryxm = ?",
                           item.getPayProcess(),item.getPersonId(),item.getDueStartMonth(),item.getDueEndMonth(),item.getDueMoney());
               }


            }else {
                //不存在缴款数据情况 todo poc待定
            }


        });

    }

    private int calculateMonthDiff(String payMonth,String localDate){

        LocalDate date1 = LocalDate.parse(localDate + "-01");
        LocalDate date2 = LocalDate.parse(payMonth + "-01");


        return  (int) ChronoUnit.MONTHS.between(date1, date2);
    }
}
